==> Mudlib-CD.00.28.tar.gz: lib/sys/state_desc.h <==
/*
   sys/state_desc.h

   Holds all textual descriptions of state descriptions of livings.
   
   Note that local changes to these arrays are done in
   /config/sys/state_desc2.h
*/

#ifndef SD_DEFINED
#include "/config/sys/state_desc2.h"
#endif

#ifndef SD_DEFINED
#define SD_DEFINED

#ifndef SD_AV_TITLES
#define SD_AV_TITLES 	({ "novice", "beginner", "apprentice", "master" })
#endif

#define SD_STAT_NAMES 	({ "STR", "DEX", "CON", "INT", "WIS", "DIS" })

#define SD_STATLEV_STR 	({ "puny", "weak", "well built", "strong",	\
			   "powerful", "musclebound", "forceful", "titanic" })
#define SD_STATLEV_DEX  ({ "stiff", "clumsy", "nimble", "agile", "swift", \
			   "athletic", "graceful", "acrobatic" })
#define SD_STATLEV_CON  ({ "infirm", "sickly", "skinny", "healthy", "robust", \
			   "tough", "sturdy", "vigorous" })
#define SD_STATLEV_INT  ({ "moronic", "dimwitted", "slow", "clever", 	\
			   "quick minded", "bright", "brilliant", "ingenious" })
#define SD_STATLEV_WIS  ({ "inane", "stupid", "idiotic", "uneducated", 	\
			   "educated", "learned",  "wise", "enlightened" })
#define SD_STATLEV_DIS  ({ "spineless", "cowardly", "frightened", "insecure",	\
			    "sound", "brave", "courageous", "heroic" })

/* Observe that the denominators below are reversed for the first two
   of the statlev descs above.
*/
#define SD_STAT_DENOM	({ "slightly ", "somewhat ", "", 		\
			   "very ", "extremely " })

#define SD_BRUTE_FACT   ({ "pacifistic", "meek", "touchy", "brutal", 	\
			   "violent"})

#define SD_HEALTH 	({ "at deaths door", "barely alive", 		\
                	   "terribly hurt", "in a very bad shape", 	\
			   "in a bad shape", "very hurt",	 	\
			   "feeling rather hurt", "hurt", 		\
                	   "somewhat hurt", "slightly hurt", 		\
			   "feeling very well" })
    
#define SD_MANA		({ "in a vegetable state", "exhausted",		  \
			   "worn down", "indisposed", "in a bad shape",   \
			   "very degraded", "rather degraded",\
			   "degraded", "somewhat degraded",		  \
			   "slightly degraded", "in full vigour" })

#define SD_COMPARE_STR  ({ "about the same strength as", 		  \
			   "a bit stronger than", "stronger than", 	  \
			   "much stronger than"})
#define SD_COMPARE_DEX  ({ "about as agile as", 			  \
			   "a bit better coordinated than", 		  \
			   "more agile than", "much more agile than" })
#define SD_COMPARE_CON  ({ "about as healthy as", "a bit healthier than", \
			   "healthier than", "much healthier than"})
#define SD_COMPARE_INT  ({ "about as smart as", "a bit smarter than",     \
			   "smarter than", "much smarter than"})
#define SD_COMPARE_WIS  ({ "about as wise as", "a bit wiser than",        \
			   "wiser than", "much wiser than"})
#define SD_COMPARE_DIS  ({ "about as brave as", "a bit braver than",      \
			   "braver than", "much braver than"})

#define SD_BEAUTY_FEMALE ({ "like the image of perfection", "gorgeous",   \
			    "fine", "attractive", "beautiful", "pretty",  \
			    "nice", "plain", "more than usually plain",   \
			    "repulsive", "ugly", "hideous" })

#define SD_BEAUTY_MALE  ({ "like the image of perfection", "wonderful",   \
			   "handsome", "attractive", "fine", "pleasant",  \
			   "nice", "coarse", "unpleasant", "repulsive",   \
			   "ugly", "hideous" })

#define SD_PANIC  	({ "secure", "calm", "uneasy", "worried", "panicky"})
#define SD_FATIGUE	({ "alert", "weary", "tired", "exhausted" })

#define SD_SOAK  	({ "drink quite a lot more", "drink a lot more",  \
		    	   "drink some more", "drink a little more",	  \
		    	   "barely drink more" })

#define SD_STUFF    	({ "eat quite a lot more", "eat a lot more",	  \
		     	   "eat some more", "eat a little more",	  \
		     	   "barely eat more" })
    
#define SD_INTOX	({ "tipsy", "intoxicated", "drunk", "tanked", 	  \
			   "blitzed", "wasted", "toasted", "pissed",	  \
			   "stoned", "obliviated" })
    
#define SD_HEADACHE	({ "mild", "uncomfortable", "bad", "serious",     \
			   "intense", "pounding", "burning", "extreme" })
    
#define SD_IMPROVE	({ "insignificant", "slight", "a little", "some", \
			   "nice", "good", "very good", "extremely good", \
		      	   "immense", "fantastic" })
	    
#define SD_GOOD_ALIGN	({ "neutral", "agreeable", "trustworthy",	  \
			   "sympathetic", "nice", "sweet", "good",	  \
			   "devout", "blessed", "saintly", "holy" })

#define SD_EVIL_ALIGN	({ "neutral", "disagreeable", "untrustworthy",    \
			   "unsympathetic", "sinister", "wicked", "nasty",\
			   "foul", "evil", "malevolent", "beastly",	  \
			   "demonic", "damned" })

#define SD_ARMOUR	({ "in prime condition", "a little worn down", 	 \
			   "in a very bad shape", "in big need for repairs", \
			   "going to break any second" })

#define SD_WEAPON_RUST	({ "no comment", "find some rust marks",	\
			   "spot some rust", "full of rust", 		\
			   "bathing in acid", "falling apart from corrosion" })

#define SD_WEAPON_COND	({ "in prime condition", "in a fine condition",	\
			   "touched by battle", "scarred by battle", 	\
			   "very scarred by battle", "in big need of a smith",	\
			   "going to break any second" })

#define SD_ENC_WEIGHT	({ "lightly burdened", "burdened", "encumbered",\
			   "heavily loaded", "over taxed",		\
			   "collapsing under your load" })

#define SD_LEVEL_MAP 	([						\
			  "goodalign" : SD_GOOD_ALIGN,			\
			  "evilalign" : SD_EVIL_ALIGN,			\
			  "statimprove" : SD_IMPROVE,			\
			  "headache" : SD_HEADACHE,			\
			  "intox" : SD_INTOX,				\
			  "stuffed" : SD_STUFF,				\
			  "soaked" : SD_SOAK,				\
			  "fatigue" : SD_FATIGUE,			\
			  "panic" : SD_PANIC,				\
			  "malebeauty" : SD_BEAUTY_MALE,		\
			  "femalebeauty" : SD_BEAUTY_FEMALE,		\
			  "mana" : SD_MANA,				\
			  "health" : SD_HEALTH,				\
			  "brute" : SD_BRUTE_FACT,			\
			  "compstr" : SD_COMPARE_STR,			\
			  "compdex" : SD_COMPARE_DEX,			\
			  "compcon" : SD_COMPARE_CON,			\
			  "compint" : SD_COMPARE_INT,			\
			  "compwis" : SD_COMPARE_WIS,			\
			  "compdis" : SD_COMPARE_DIS,			\
			  "statstr" : SD_STATLEV_STR,			\
			  "statdex" : SD_STATLEV_DEX,			\
			  "statcon" : SD_STATLEV_CON,			\
			  "statint" : SD_STATLEV_INT,			\
			  "statwis" : SD_STATLEV_WIS,			\
			  "statdis" : SD_STATLEV_DIS,			\
			  "mortal" : SD_AV_TITLES,		     	\
			  "armour" : SD_ARMOUR,				\
			  "weaponrust" : SD_WEAPON_RUST,		\
			  "weaponcond" : SD_WEAPON_COND,		\
			  "encumberance": SD_ENC_WEIGHT,		\
		       ])
#endif

==> Mudlib-CD.00.30.tar.gz: lib/sys/state_desc.h <==
/*
   sys/state_desc.h

   Holds all textual descriptions of state descriptions of livings.
   
   Note that local changes to these arrays are done in
   /config/sys/state_desc2.h
*/

#ifndef SD_DEFINED
#include "/config/sys/state_desc2.h"
#endif

#ifndef SD_DEFINED
#define SD_DEFINED

#ifndef SD_AV_TITLES
#define SD_AV_TITLES 	({ "novice", "beginner", "apprentice", "master" })
#endif

#define SD_STAT_NAMES 	({ "STR", "DEX", "CON", "INT", "WIS", "DIS" })

#define SD_STATLEV_STR 	({ "puny", "weak", "well built", "strong",	\
			   "powerful", "musclebound", "forceful", "titanic" })
#define SD_STATLEV_DEX  ({ "stiff", "clumsy", "nimble", "agile", "swift", \
			   "athletic", "graceful", "acrobatic" })
#define SD_STATLEV_CON  ({ "infirm", "sickly", "skinny", "healthy", "robust", \
			   "tough", "sturdy", "vigorous" })
#define SD_STATLEV_INT  ({ "moronic", "dimwitted", "slow", "clever", 	\
			   "quick minded", "bright", "brilliant", "ingenious" })
#define SD_STATLEV_WIS  ({ "inane", "stupid", "idiotic", "uneducated", 	\
			   "educated", "learned",  "wise", "enlightened" })
#define SD_STATLEV_DIS  ({ "spineless", "cowardly", "frightened", "insecure", \
			    "sound", "brave", "courageous", "heroic" })

/* Observe that the denominators below are reversed for the first two
   of the statlev descs above.
*/
#define SD_STAT_DENOM	({ "slightly ", "somewhat ", "", 		\
			   "very ", "extremely " })

#define SD_BRUTE_FACT   ({ "pacifistic", "meek", "touchy", "brutal", 	\
			   "violent"})

#define SD_HEALTH 	({ "at death's door", "barely alive", 		\
                	   "terribly hurt", "in a very bad shape", 	\
			   "in a bad shape", "very hurt",	 	\
			   "feeling rather hurt", "hurt", 		\
                	   "somewhat hurt", "slightly hurt", 		\
			   "feeling very well" })
    
#define SD_MANA		({ "in a vegetable state", "exhausted",		  \
			   "worn down", "indisposed", "in a bad shape",   \
			   "very degraded", "rather degraded",\
			   "degraded", "somewhat degraded",		  \
			   "slightly degraded", "in full vigour" })

#define SD_COMPARE_STR  ({ "about the same strength as", 		  \
			   "a bit stronger than", "stronger than", 	  \
			   "much stronger than"})
#define SD_COMPARE_DEX  ({ "about as agile as", 			  \
			   "a bit better coordinated than", 		  \
			   "more agile than", "much more agile than" })
#define SD_COMPARE_CON  ({ "about as healthy as", "a bit healthier than", \
			   "healthier than", "much healthier than"})
#define SD_COMPARE_INT  ({ "about as smart as", "a bit smarter than",     \
			   "smarter than", "much smarter than"})
#define SD_COMPARE_WIS  ({ "about as wise as", "a bit wiser than",        \
			   "wiser than", "much wiser than"})
#define SD_COMPARE_DIS  ({ "about as brave as", "a bit braver than",      \
			   "braver than", "much braver than"})

#define SD_BEAUTY_FEMALE ({ "like the image of perfection", "gorgeous",   \
			    "fine", "attractive", "beautiful", "pretty",  \
			    "nice", "plain", "more than usually plain",   \
			    "repulsive", "ugly", "hideous" })

#define SD_BEAUTY_MALE  ({ "like the image of perfection", "wonderful",   \
			   "handsome", "attractive", "fine", "pleasant",  \
			   "nice", "coarse", "unpleasant", "repulsive",   \
			   "ugly", "hideous" })

#define SD_PANIC  	({ "secure", "calm", "uneasy", "worried", "panicky"})
#define SD_FATIGUE	({ "alert", "weary", "tired", "exhausted" })

#define SD_SOAK  	({ "drink quite a lot more", "drink a lot more",  \
		    	   "drink some more", "drink a little more",	  \
		    	   "barely drink more" })

#define SD_STUFF    	({ "eat quite a lot more", "eat a lot more",	  \
		     	   "eat some more", "eat a little more",	  \
		     	   "barely eat more" })
    
#define SD_INTOX	({ "tipsy", "intoxicated", "drunk", "tanked", 	  \
			   "blitzed", "wasted", "toasted", "pissed",	  \
			   "stoned", "obliviated" })
    
#define SD_HEADACHE	({ "mild", "uncomfortable", "bad", "serious",     \
			   "intense", "pounding", "burning", "extreme" })
    
#define SD_IMPROVE	({ "insignificant", "slight", "a little", "some", \
			   "nice", "good", "very good", "extremely good", \
		      	   "immense", "fantastic" })
	    
#define SD_GOOD_ALIGN	({ "neutral", "agreeable", "trustworthy",	  \
			   "sympathetic", "nice", "sweet", "good",	  \
			   "devout", "blessed", "saintly", "holy" })

#define SD_EVIL_ALIGN	({ "neutral", "disagreeable", "untrustworthy",    \
			   "unsympathetic", "sinister", "wicked", "nasty",\
			   "foul", "evil", "malevolent", "beastly",	  \
			   "demonic", "damned" })

#define SD_ARMOUR	({ "in prime condition", "a little worn down", 	 \
			   "in a very bad shape", "in big need for repairs", \
			   "going to break any second" })

#define SD_WEAPON_RUST	({ "no comment", "find some rust marks",	\
			   "spot some rust", "full of rust", 		\
			   "bathing in acid", "falling apart from corrosion" })

#define SD_WEAPON_COND	({ "in prime condition", "in a fine condition",	\
			   "touched by battle", "scarred by battle", 	\
			   "very scarred by battle", "in big need of a smith", \
			   "going to break any second" })

#define SD_ENC_WEIGHT	({ "lightly burdened", "burdened", "encumbered",\
			   "heavily loaded", "over taxed",		\
			   "collapsing under your load" })

#define SD_LEVEL_MAP 	([						\
			  "goodalign" : SD_GOOD_ALIGN,			\
			  "evilalign" : SD_EVIL_ALIGN,			\
			  "statimprove" : SD_IMPROVE,			\
			  "headache" : SD_HEADACHE,			\
			  "intox" : SD_INTOX,				\
			  "stuffed" : SD_STUFF,				\
			  "soaked" : SD_SOAK,				\
			  "fatigue" : SD_FATIGUE,			\
			  "panic" : SD_PANIC,				\
			  "malebeauty" : SD_BEAUTY_MALE,		\
			  "femalebeauty" : SD_BEAUTY_FEMALE,		\
			  "mana" : SD_MANA,				\
			  "health" : SD_HEALTH,				\
			  "brute" : SD_BRUTE_FACT,			\
			  "compstr" : SD_COMPARE_STR,			\
			  "compdex" : SD_COMPARE_DEX,			\
			  "compcon" : SD_COMPARE_CON,			\
			  "compint" : SD_COMPARE_INT,			\
			  "compwis" : SD_COMPARE_WIS,			\
			  "compdis" : SD_COMPARE_DIS,			\
			  "statstr" : SD_STATLEV_STR,			\
			  "statdex" : SD_STATLEV_DEX,			\
			  "statcon" : SD_STATLEV_CON,			\
			  "statint" : SD_STATLEV_INT,			\
			  "statwis" : SD_STATLEV_WIS,			\
			  "statdis" : SD_STATLEV_DIS,			\
			  "mortal" : SD_AV_TITLES,		     	\
			  "armour" : SD_ARMOUR,				\
			  "weaponrust" : SD_WEAPON_RUST,		\
			  "weaponcond" : SD_WEAPON_COND,		\
			  "encumberance": SD_ENC_WEIGHT,		\
		       ])
#endif
